| Title: | Fetch Data from Plataforma +Brasil (SICONV) |
|---|---|
| Description: | Fetch data on targeted public investments from Plataforma +Brasil (SICONV) <http://plataformamaisbrasil.gov.br/>, the responsible system for requests, execution, and monitoring of federal discretionary transfers in Brazil. |
| Authors: | Fernando Meireles [aut, cre] (ORCID: <https://orcid.org/0000-0002-7027-2058>), Marcus Vinícius de Sá Torres [aut] (ORCID: <https://orcid.org/0000-0002-9647-1418>) |
| Maintainer: | Fernando Meireles <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.2.900 |
| Built: | 2026-06-03 09:17:19 UTC |
| Source: | https://github.com/meirelesff/siconvr |
get_siconv() is the package's workhorse. It downloads, cleans, and
returns one of the several datasets maintained by Plataforma +Brasil on federal
targeted transfers in Brazil. Under the hoods, the function handles GET requests,
downloads and stores intermediary files, and reads as fast as possible the data
to a tibble format convenient for use in analysis.
get_siconv(dataset = NULL, encoding = "UTF-8", cache = TRUE, verbose = TRUE)get_siconv(dataset = NULL, encoding = "UTF-8", cache = TRUE, verbose = TRUE)
dataset |
A
When not specified, |
encoding |
Encoding used to read raw files. Defaults to "UTF-8", but users might need to change this option to other valid options (e.g., "latin1") if data are returned with uncommon characters. |
cache |
Should the function maintain a local copy of the data? To save
both time and SICONV's server resources, this defaults to |
verbose |
Should the function display messages and progress bar? Defaults
to |
A tibble contantaining the requested data as defined in the
dataset argument. Use the show_schema function to get detailed information
on available variables and information.
get_siconv() needs an internet connection to download data in case it
does not found a cache folder with raw data from a previous request. Be aware that instability
in the Plataforma +Brasil server might produce error messagens, in which case users
should try waiting before rerunning their requests.
## Not run: df <- get_siconv(dataset = "propostas")## Not run: df <- get_siconv(dataset = "propostas")
show_schema() downloads, unzips, and show in a web browser Plataforma +Brasil's
full database documentation, including its schema and other usefull information.
Docs are downloaded to a folder in the working directory.
show_schema(verbose = TRUE, browser = TRUE)show_schema(verbose = TRUE, browser = TRUE)
verbose |
Should the function display messages and progress bar? Defaults
to |
browser |
Should the function open a web browser to display the docs?
Defaults to |
show_schema() is most usefull for its side effect of downloading,
when needed, and opening Plataforma +Brasil's documentation, but is also silently
returns a string containing the path to the docs' index file.
show_schema() needs an internet connection to download data in case it
does not found a cache folder with the docs from a previous request. Be aware that instability
in the Plataforma +Brasil server might produce error messagens, in which case users
should try waiting before rerunning the function.
## Not run: show_schema()## Not run: show_schema()